@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -220,9 +220,9 @@ class TranslationServiceAsyncClient:
 
             from google.cloud import translate_v3beta1
 
-            def sample_translate_text():
+            async def sample_translate_text():
                 # Create a client
-                client = translate_v3beta1.TranslationServiceClient()
+                client = translate_v3beta1.TranslationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = translate_v3beta1.TranslateTextRequest(
@@ -232,7 +232,7 @@ class TranslationServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.translate_text(request=request)
+                response = await client.translate_text(request=request)
 
                 # Handle the response
                 print(response)
@@ -269,7 +269,12 @@ class TranslationServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -291,9 +296,9 @@ class TranslationServiceAsyncClient:
 
             from google.cloud import translate_v3beta1
 
-            def sample_detect_language():
+            async def sample_detect_language():
                 # Create a client
-                client = translate_v3beta1.TranslationServiceClient()
+                client = translate_v3beta1.TranslationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = translate_v3beta1.DetectLanguageRequest(
@@ -302,7 +307,7 @@ class TranslationServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.detect_language(request=request)
+                response = await client.detect_language(request=request)
 
                 # Handle the response
                 print(response)
@@ -402,7 +407,12 @@ class TranslationServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -421,14 +431,13 @@ class TranslationServiceAsyncClient:
         r"""Returns a list of supported languages for
         translation.
 
-
         .. code-block:: python
 
             from google.cloud import translate_v3beta1
 
-            def sample_get_supported_languages():
+            async def sample_get_supported_languages():
                 # Create a client
-                client = translate_v3beta1.TranslationServiceClient()
+                client = translate_v3beta1.TranslationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = translate_v3beta1.GetSupportedLanguagesRequest(
@@ -436,7 +445,7 @@ class TranslationServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_supported_languages(request=request)
+                response = await client.get_supported_languages(request=request)
 
                 # Handle the response
                 print(response)
@@ -551,7 +560,12 @@ class TranslationServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -570,9 +584,9 @@ class TranslationServiceAsyncClient:
 
             from google.cloud import translate_v3beta1
 
-            def sample_translate_document():
+            async def sample_translate_document():
                 # Create a client
-                client = translate_v3beta1.TranslationServiceClient()
+                client = translate_v3beta1.TranslationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 document_input_config = translate_v3beta1.DocumentInputConfig()
@@ -585,7 +599,7 @@ class TranslationServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.translate_document(request=request)
+                response = await client.translate_document(request=request)
 
                 # Handle the response
                 print(response)
@@ -623,7 +637,12 @@ class TranslationServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -646,14 +665,13 @@ class TranslationServiceAsyncClient:
         use google.longrunning.Operation.name to poll the status
         of the call.
 
-
         .. code-block:: python
 
             from google.cloud import translate_v3beta1
 
-            def sample_batch_translate_text():
+            async def sample_batch_translate_text():
                 # Create a client
-                client = translate_v3beta1.TranslationServiceClient()
+                client = translate_v3beta1.TranslationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 input_configs = translate_v3beta1.InputConfig()
@@ -675,7 +693,7 @@ class TranslationServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -717,7 +735,12 @@ class TranslationServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -753,14 +776,13 @@ class TranslationServiceAsyncClient:
         google.longrunning.Operation.name to poll the status of
         the call.
 
-
         .. code-block:: python
 
             from google.cloud import translate_v3beta1
 
-            def sample_batch_translate_document():
+            async def sample_batch_translate_document():
                 # Create a client
-                client = translate_v3beta1.TranslationServiceClient()
+                client = translate_v3beta1.TranslationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 input_configs = translate_v3beta1.BatchDocumentInputConfig()
@@ -782,7 +804,7 @@ class TranslationServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -911,7 +933,12 @@ class TranslationServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -937,14 +964,13 @@ class TranslationServiceAsyncClient:
         r"""Creates a glossary and returns the long-running operation.
         Returns NOT_FOUND, if the project doesn't exist.
 
-
         .. code-block:: python
 
             from google.cloud import translate_v3beta1
 
-            def sample_create_glossary():
+            async def sample_create_glossary():
                 # Create a client
-                client = translate_v3beta1.TranslationServiceClient()
+                client = translate_v3beta1.TranslationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 glossary = translate_v3beta1.Glossary()
@@ -960,7 +986,7 @@ class TranslationServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1027,7 +1053,12 @@ class TranslationServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1053,14 +1084,13 @@ class TranslationServiceAsyncClient:
         r"""Lists glossaries in a project. Returns NOT_FOUND, if the project
         doesn't exist.
 
-
         .. code-block:: python
 
             from google.cloud import translate_v3beta1
 
-            def sample_list_glossaries():
+            async def sample_list_glossaries():
                 # Create a client
-                client = translate_v3beta1.TranslationServiceClient()
+                client = translate_v3beta1.TranslationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = translate_v3beta1.ListGlossariesRequest(
@@ -1071,7 +1101,7 @@ class TranslationServiceAsyncClient:
                 page_result = client.list_glossaries(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1177,12 +1207,20 @@ class TranslationServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListGlossariesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1200,14 +1238,13 @@ class TranslationServiceAsyncClient:
         r"""Gets a glossary. Returns NOT_FOUND, if the glossary doesn't
         exist.
 
-
         .. code-block:: python
 
             from google.cloud import translate_v3beta1
 
-            def sample_get_glossary():
+            async def sample_get_glossary():
                 # Create a client
-                client = translate_v3beta1.TranslationServiceClient()
+                client = translate_v3beta1.TranslationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = translate_v3beta1.GetGlossaryRequest(
@@ -1215,7 +1252,7 @@ class TranslationServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_glossary(request=request)
+                response = await client.get_glossary(request=request)
 
                 # Handle the response
                 print(response)
@@ -1284,7 +1321,12 @@ class TranslationServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1302,14 +1344,13 @@ class TranslationServiceAsyncClient:
         glossary isn't created yet. Returns NOT_FOUND, if the glossary
         doesn't exist.
 
-
         .. code-block:: python
 
             from google.cloud import translate_v3beta1
 
-            def sample_delete_glossary():
+            async def sample_delete_glossary():
                 # Create a client
-                client = translate_v3beta1.TranslationServiceClient()
+                client = translate_v3beta1.TranslationServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = translate_v3beta1.DeleteGlossaryRequest(
@@ -1321,7 +1362,7 @@ class TranslationServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1393,7 +1434,12 @@ class TranslationServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1415,7 +1461,9 @@ class TranslationServiceAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-translate",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-translate",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
